-- #########################################################################
-- #                                                                       #
-- # License GPLv3: https://www.gnu.org/licenses/gpl-3.0.html              #
-- #                                                                       #
-- # This program is free software; you can redistribute it and/or modify  #
-- # it under the terms of the GNU General Public License version 2 as     #
-- # published by the Free Software Foundation.                            #
-- #                                                                       #
-- # This program is distributed in the hope that it will be useful        #
-- # but WITHOUT ANY WARRANTY; without even the implied warranty of        #
-- # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
-- # GNU General Public License for more details.                          #
-- #                                                                       #
-- #########################################################################
--
-- =============================================================================
-- ETHOS menu library for Battery Capacity
-- File:   : menuLib.lua
-- Author  : RNDr.Vladimir Pribyl, CSc. (VPRHELI)
-- History : Date        Version Author   Comment
--           ----------  ------- -------- ------------------------------------
--           1ž.0ě.2025  0.0.1   VPRHELI  initial version
-- =============================================================================

local menuLib     = {}
local conf        = nil
local libs        = nil

-- #################################################################### 
-- # menuLib.init                                                     #
-- ####################################################################
function menuLib.init(param_conf, param_libs)
  --print ("### menuLib.init()")
  conf   = param_conf  
  libs   = param_libs

  return menuLib
end 

-- #################################################################### 
-- # menuLib.configure                                                #
-- #    Widget Configuration options                                  #
-- #################################################################### 
function menuLib.configure(widget)
  print ("### menuLib.configure()")
  
  local cellsEnabled = widget.VoltageSensor
  -- Artifitial Horizon
  line = form.addLine(libs.utils.translate ("menuname") .. "  " .. conf.version)
  
  -- Roll Sensor
  line = form.addLine(libs.utils.translate("mnRoll"))
  form.addSourceField(line, nil, function() return widget.idRoll end,
                                 function (value)
                                    if value:name() == "---" then
                                      widget.idRoll = nil
                                    else
                                      widget.idRoll = value
                                    end
                                 end)    
                               
  -- Pitch Sensor
  line = form.addLine(libs.utils.translate("mnPitch"))
  form.addSourceField(line, nil, function() return widget.idPitch end,
                                 function (value)
                                    if value:name() == "---" then
                                      widget.idPitch = nil
                                    else
                                      widget.idPitch = value
                                    end
                                 end)        
                               
  -- Altitude Sensor
  line = form.addLine(libs.utils.translate("mnAlt"))
  form.addSourceField(line, nil, function() return widget.idAlt end,
                                 function (value)
                                    if value:name() == "---" then
                                      widget.idAlt = nil
                                    else
                                      widget.idAlt = value
                                    end
                                 end)                                 
                               
  -- Vertical Speed Sensor
  line = form.addLine(libs.utils.translate("mnVertSpeed"))
  form.addSourceField(line, nil, function() return widget.idVertSpeed end,
                                 function (value)
                                    if value:name() == "---" then
                                      widget.idVertSpeed = nil
                                    else
                                      widget.idVertSpeed = value
                                    end
                                 end)                                  
                               
  -- Land color
  line = form.addLine(libs.utils.translate("mnColorLand"))
  form.addColorField(line, nil, function() return widget.colorLand end, function(color) widget.colorLand = color end)

  -- Sky color
  line = form.addLine(libs.utils.translate("mnColorSky"))
  form.addColorField(line, nil, function() return widget.colorSky end, function(color) widget.colorSky = color end)

end

return menuLib